@@ -8,6 +8,8 @@ from wsgiref.simple_server import make_server
 
 import muntjac
 
+from muntjac.util import InMemorySession
+
 from muntjac.terminal.gwt.server.application_servlet import ApplicationServlet
 
 from muntjac.demo.HelloWorld import HelloWorld
@@ -21,21 +23,17 @@ from paste.session import SessionMiddleware
 from paste.fileapp import DirectoryApp
 
 
-helloServlet = ApplicationServlet(HelloWorld)
-hello = SessionMiddleware(helloServlet)
+hello = ApplicationServlet(HelloWorld)
 
-calcServlet = ApplicationServlet(Calc)
-calc = SessionMiddleware(calcServlet)
+calc = ApplicationServlet(Calc)
 
-addressServlet = ApplicationServlet(SimpleAddressBook)
-address = SessionMiddleware(addressServlet)
+address = ApplicationServlet(SimpleAddressBook)
 
-tunesServlet = ApplicationServlet(MuntjacTunesLayout)
-tunes = SessionMiddleware(tunesServlet)
+tunes = ApplicationServlet(MuntjacTunesLayout)
 
-samplerServlet = ApplicationServlet(SamplerApplication,
+sampler = ApplicationServlet(SamplerApplication,
         widgetset='com.vaadin.demo.sampler.gwt.SamplerWidgetSet')
-sampler = SessionMiddleware(samplerServlet)
+
 
 urlmap = URLMap({})
 urlmap['/hello'] = hello
@@ -44,11 +42,20 @@ urlmap['/address'] = address
 urlmap['/tunes'] = tunes
 urlmap['/sampler'] = sampler
 
+ws_app = DirectoryApp(join(dirname(muntjac.__file__), 'public', 'VAADIN'))
+urlmap['/VAADIN'] = ws_app
 
-if __name__ == '__main__':
+
+def main():
     logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
 
-    wsapp = DirectoryApp(join(dirname(muntjac.__file__), 'public', 'VAADIN'))
-    urlmap['/VAADIN'] = wsapp
+    url_map = SessionMiddleware(urlmap, session_class=InMemorySession)
 
-    make_server('localhost', 8080, urlmap).serve_forever()
+    print 'Serving on port: 8080'
+    make_server('localhost', 8080, url_map).serve_forever()
+
+
+if __name__ == '__main__':
+    ## $ python -m cProfile -o /tmp/demo.prof muntjac/demo/main.py
+    #pstats.Stats("/tmp/demo.prof").sort_stats('time').print_stats(20)
+    main()
