@@ -30,6 +30,8 @@ from wsgiref.simple_server import make_server
 from paste.session import SessionMiddleware
 from paste.fileapp import DirectoryApp, FileApp
 
+from muntjac.util import InMemorySession
+
 from muntjac.terminal.gwt.server.application_servlet import ApplicationServlet
 from muntjac.demo.main import urlmap
 from muntjac.test.suite import main as test
@@ -46,7 +48,7 @@ def muntjac(applicationClass, host='localhost', port=8880, nogui=False,
     wsgi_app = ApplicationServlet(applicationClass, debug=debug,
             *args, **kw_args)
 
-    wsgi_app = SessionMiddleware(wsgi_app)  # wrap in middleware
+    wsgi_app = SessionMiddleware(wsgi_app, session_class=InMemorySession)
 
     url = 'http://%s:%d/' % (host, port)
 
@@ -69,7 +71,7 @@ def main(args=sys.argv[1:]):
 
     parser = OptionParser(
         usage='usage: muntjac [options]',
-        version='Muntjac Version %s' % '1.0.3')
+        version='Muntjac Version %s' % '1.0.4')
 
     parser.add_option('-t', '--test', action='store_true',
         help='run tests and exit')
@@ -118,6 +120,8 @@ def main(args=sys.argv[1:]):
             ctxapp = DirectoryApp(join(opts.contextRoot, 'VAADIN'))
             urlmap['/VAADIN'] = ctxapp
 
+        app = SessionMiddleware(urlmap, session_class=InMemorySession)
+
         url = 'http://%s:%d/' % (opts.host, opts.port)
 
         if not opts.nogui:
@@ -125,7 +129,7 @@ def main(args=sys.argv[1:]):
 
         print 'Serving at: %s' % url
 
-        httpd = make_server(opts.host, opts.port, urlmap)
+        httpd = make_server(opts.host, opts.port, app)
 
         try:
             httpd.serve_forever()
